@@ -412,6 +412,19 @@ class SensiML(object):
     def list_sandboxes(self, get_objects=False):
         """List all sandboxes for the active project.
 
+        Args:
+            get_objects (bool, False): Also return the sandbox objects.
+
+        """
+        print("list_sanboxes has been deprecated in favor of list_pipelines.")
+        if self._project is None:
+            raise Exception("Project must be set to perform this action.")
+        return self._project._sandboxes.build_sandbox_list()
+
+    @print_list
+    def list_pielines(self, get_objects=False):
+        """List all piplines for the active project.
+
         Args:
             get_objects (bool, False): Also return the sandbox objects.
 
