@@ -493,7 +493,7 @@ class Sandbox(object):
             if data["number_of_pages"] > 1:
                 print(
                     "To get more pages, use: \n"
-                    + "next_results, next_stats = dsk.pipeline.get_results(page_index=<desired page number>)."
+                    + "next_results, next_stats = client.pipeline.get_results(page_index=<desired page number>)."
                 )
 
         summary = pd.DataFrame(data.get("summary", [])).fillna("")
