@@ -282,9 +282,11 @@ class DCLProject:
             ]
         )
 
-        return self._list_table(
-            "CaptureLabelValue", fields, fk_fields, query_filter
-        ).sort_values(by=["capture", "segmenter", "capture_sample_sequence_start"])
+        return (
+            self._list_table("CaptureLabelValue", fields, fk_fields, query_filter)
+            .reset_index(drop=True)
+            .sort_values(by=["capture", "segmenter", "capture_sample_sequence_start"])
+        )
 
     def get_capture_metadata(self, capture: str) -> DataFrame:
         "returns a dataframe containing the metadata associated with this capture"
@@ -346,7 +348,7 @@ class DCLProject:
                 tmp_df.loc[label[0] : label[1]],
                 segment_id=index,
                 session=label[5],
-                label=label[3],
+                label_value=label[3],
                 uuid=label[2],
                 capture=label[4],
             )
@@ -480,57 +482,15 @@ class DCLProject:
             capture = self.get_capture(capture_name)
             M.append(capture)
 
-            capture.describe().loc["max"].max()
-
-            cmap = plt.cm.rainbow
-
-            labels = list(class_map.keys())
-
-            delta = 1 / len(labels)
-            label_float = np.arange(0, 1, delta)
-            label_float[-1] = 1.0
-
-            label_colors = {
-                labels[index]: cmap(x) for index, x in enumerate(label_float)
-            }
-            label_legend = [
-                Line2D([0], [0], color=cmap(x), lw=4) for x in label_float
-            ] + [Line2D([0], [0], color="white", lw=4)]
-
-            for _, seg in segments.iterrows():
-                y_origin = (
-                    capture.describe().loc["min"].min() if ylim is None else ylim[0]
-                )
-                x_origin = seg["capture_sample_sequence_start"] + current_start
-                x_final = (
-                    seg["capture_sample_sequence_end"]
-                    - seg["capture_sample_sequence_start"]
-                )
-                y_final = (
-                    capture.describe().loc["max"].max() - y_origin
-                    if ylim is None
-                    else ylim[1] - ylim[0]
-                )
-
-                currentAxis.add_artist(
-                    plt.Rectangle(
-                        (x_origin, y_origin),
-                        x_final,
-                        y_final,
-                        alpha=0.2,
-                        color=label_colors[seg["label_value"]],
-                    )
-                )
-
-            currentAxis.legend(label_legend, labels + [""])
-
-            currentAxis.text(
-                current_start,
-                0 if ylim is None else ylim[0],
-                capture_name,
-                style="italic",
-                rotation=90,
-                # bbox={"facecolor": "grey", "alpha": 0.5, "pad": 10},
+            plot_segments_on_capture(
+                capture,
+                segments,
+                capture_name=capture_name,
+                labels=list(class_map.keys()),
+                current_start=current_start,
+                ylim=ylim,
+                figsize=figsize,
+                currentAxis=currentAxis,
             )
 
             current_start += capture.shape[0]
@@ -560,3 +520,66 @@ class DCLProject:
         )
 
         return capture.reset_index(drop=True)
+
+
+def plot_segments_on_capture(
+    capture,
+    segments,
+    capture_name,
+    labels=None,
+    current_start=0,
+    ylim=None,
+    figsize: Tuple = (30, 8),
+    currentAxis=None,
+):
+
+    if currentAxis is None:
+        plt.figure(figsize=figsize)
+        currentAxis = plt.gca()
+
+    cmap = plt.cm.rainbow
+
+    if labels is None:
+        labels = segments.label_value.unique().tolist()
+
+    delta = 1 / len(labels)
+    label_float = np.arange(0, 1, delta)
+    label_float[-1] = 1.0
+
+    label_colors = {labels[index]: cmap(x) for index, x in enumerate(label_float)}
+    label_legend = [Line2D([0], [0], color=cmap(x), lw=4) for x in label_float] + [
+        Line2D([0], [0], color="white", lw=4)
+    ]
+
+    for _, seg in segments.iterrows():
+        y_origin = capture.describe().loc["min"].min() if ylim is None else ylim[0]
+        x_origin = seg["capture_sample_sequence_start"] + current_start
+        x_final = (
+            seg["capture_sample_sequence_end"] - seg["capture_sample_sequence_start"]
+        )
+        y_final = (
+            capture.describe().loc["max"].max() - y_origin
+            if ylim is None
+            else ylim[1] - ylim[0]
+        )
+
+        currentAxis.add_artist(
+            plt.Rectangle(
+                (x_origin, y_origin),
+                x_final,
+                y_final,
+                alpha=0.2,
+                color=label_colors[seg["label_value"]],
+            )
+        )
+
+    currentAxis.legend(label_legend, labels + [""])
+
+    currentAxis.text(
+        current_start,
+        0 if ylim is None else ylim[0],
+        capture_name,
+        style="italic",
+        rotation=90,
+        # bbox={"facecolor": "grey", "alpha": 0.5, "pad": 10},
+    )
