@@ -3,6 +3,8 @@ from sensiml.method_calls.capturefilecall import CaptureFileCall
 from sensiml.method_calls.querycall import QueryCall
 from sensiml.method_calls.functioncall import FunctionCall
 from sensiml.method_calls.trainandvalidationcall import TrainAndValidationCall
+from sensiml.method_calls.augmentationcall import AugmentationCall
+from sensiml.method_calls.augmentationcallset import AugmentationCallSet
 from sensiml.method_calls.generatorcall import GeneratorCall
 from sensiml.method_calls.generatorcallset import GeneratorCallSet
 from sensiml.method_calls.selectorcall import SelectorCall
@@ -18,6 +20,8 @@ __all__ = [
     "QueryCall",
     "FeatureFileCall",
     "TrainingAlgorithmCall",
+    "AugmentationCall",
+    "AugmentationCallSet",
     "GeneratorCall",
     "GeneratorCallSet",
     "SelectorCall",
