@@ -64,7 +64,7 @@ class Pipeline(object):
 
         self._sandbox = self._project.sandboxes.get_or_create_sandbox(self._id)
 
-        logger.debug("kb_dsk_pipeline_instance:" + self._id)
+        logger.debug("pipeline_instance:" + self._id)
 
     @property
     def name(self):
@@ -464,18 +464,18 @@ class Pipeline(object):
         Example:
             .. code-block:: python
 
-                activity_data = dsk.datasets.load_activity_raw()
-                dsk.upload_dataframe('activity_data.csv', activity_data, force=True)
+                activity_data = client.datasets.load_activity_raw()
+                client.upload_dataframe('activity_data.csv', activity_data, force=True)
 
-                dsk.pipeline.reset()
-                dsk.pipeline.set_input_data('activity_data.csv',
+                client.pipeline.reset()
+                client.pipeline.set_input_data('activity_data.csv',
                                             data_columns = ['accelx', 'accely', 'accelz', 'gyrox', 'gyroy', 'gyroz'],
                                             group_columns = ['Subject','Class', 'Rep'],
                                             label_column = 'Class')
 
-                dsk.pipeline.add_transform("Windowing", params={"window_size": 100, "delta": 100 })
+                client.pipeline.add_transform("Windowing", params={"window_size": 100, "delta": 100 })
 
-                results, summary = dsk.pipeline.auto({'seed': 'Basic Features',
+                results, summary = client.pipeline.auto({'seed': 'Basic Features',
                                                     'params':{"search_steps": ['selectorset', 'tvo'],
                                                                 "population_size": 10,
                                                                 "iterations": 1,
@@ -554,7 +554,7 @@ class Pipeline(object):
                         'Hierarchical Clustering with Neuron Optimization': {'number_of_neurons':[10,20]}
                         }
 
-            results, stats = dsk.pipeline.grid_search(grid_params)
+            results, stats = client.pipeline.grid_search(grid_params)
 
         """
 
@@ -894,20 +894,20 @@ class Pipeline(object):
 
         Examples:
             >>> # Add a single feature generator
-            >>> dsk.pipeline.add_feature_generator([{'name': 'Downsample', 'params': {'new_length': 5}}, {'name': 'Mean'}],
+            >>> client.pipeline.add_feature_generator([{'name': 'Downsample', 'params': {'new_length': 5}}, {'name': 'Mean'}],
                                                    function_defaults = {'columns': sensor_columns})
 
             >>> # Call multiple functions by name when they use the same same function defaults
-            >>> dsk.pipeline.add_feature_generator(['Mean', 'Standard Deviation', 'Skewness', 'Kurtosis', '25th Percentile',
+            >>> client.pipeline.add_feature_generator(['Mean', 'Standard Deviation', 'Skewness', 'Kurtosis', '25th Percentile',
                                                    '75th Percentile', '100th Percentile', 'Zero Crossing Rate'],
                                                    function_defaults = {'columns': sensor_columns})
 
             >>> # Call multiple functions using function defaults
-            >>> dsk.pipeline.add_feature_generator([{'name': 'Downsample', 'params': {'new_length': 5}}, {'name': 'Mean'}],
+            >>> client.pipeline.add_feature_generator([{'name': 'Downsample', 'params': {'new_length': 5}}, {'name': 'Mean'}],
                                                     function_defaults = {'columns': sensor_columns})
 
             >>> # Call multiple functions by subtype which use different parameters; note all subtypes will take the same inputs
-            >>> dsk.pipeline.add_feature_generator([{'subtype_call': 'Area', 'params': {'sample_rate': 100, 'smoothing_factor': 9}},
+            >>> client.pipeline.add_feature_generator([{'subtype_call': 'Area', 'params': {'sample_rate': 100, 'smoothing_factor': 9}},
                                                     {'subtype_call': 'Time', 'params': {'sample_rate': 100}},
                                                     {'subtype_call': 'Rate of Change'},
                                                     {'subtype_call': 'Statistical'},
@@ -919,14 +919,14 @@ class Pipeline(object):
                                                    )
 
             >>> # Mix subtype and specify additional feature generators
-            >>> dsk.pipeline.add_feature_generator([{'subtype_call': 'Statistical'},
+            >>> client.pipeline.add_feature_generator([{'subtype_call': 'Statistical'},
                                                     {'name': 'Downsample', 'params': {'new_length': 5}},
                                                     ],
                                                     function_defaults={'columns': sensor_columns},
                                                     )
 
             >>> # Call the same feature generators multiple times with different parameters
-            >>> dsk.pipeline.add_feature_generator([{'name': 'Downsample', 'params': {'new_length': 5, 'columns': sensor_columns[0]}},
+            >>> client.pipeline.add_feature_generator([{'name': 'Downsample', 'params': {'new_length': 5, 'columns': sensor_columns[0]}},
                                                     {'name': 'Downsample', 'params': {'new_length': 12}},
                                                     ],
                                                     function_defaults={'columns': sensor_columns},
@@ -959,10 +959,10 @@ class Pipeline(object):
 
         else:
             print(
-                "Feature Generator was improperly specified. See Documentation (dsk.pipeline.add_feature_generator?) for examples."
+                "Feature Generator was improperly specified. See Documentation (client.pipeline.add_feature_generator?) for examples."
             )
             raise InvalidParameterException(
-                "Feature Generator was improperly specified. See Documentation (dsk.pipeline.add_feature_generator?) for examples."
+                "Feature Generator was improperly specified. See Documentation (client.pipeline.add_feature_generator?) for examples."
             )
 
         return self._add_feature_generator(
@@ -977,7 +977,7 @@ class Pipeline(object):
             params (dict, {}): Parameters of the feature selector set.
 
         Examples:
-            >>> dsk.pipeline.add_feature_selector([{"name":"Recursive Feature Elimination", "params":{"method":"Log R"}}],
+            >>> client.pipeline.add_feature_selector([{"name":"Recursive Feature Elimination", "params":{"method":"Log R"}}],
             >>>                                    params = {"number_of_features":20})
         """
 
@@ -992,7 +992,7 @@ class Pipeline(object):
             params (dict, {}): Parameters of the feature selector set.
 
         Examples:
-            >>> dsk.pipeline.add_augmentation([{"name": "Add Noise", "params": {"scale": [0.05, 0.1, 0.15 ],  # , 0.1, 0.15
+            >>> client.pipeline.add_augmentation([{"name": "Add Noise", "params": {"scale": [0.05, 0.1, 0.15 ],  # , 0.1, 0.15
             >>>                                                                 "target_labels": ['idle','walking'],
             >>>                                                                 "target_sensors": ['AccelerometerX', 'GyroscopeX']
             >>>                                                                }}
@@ -1049,10 +1049,10 @@ class Pipeline(object):
             params (dict, optional): Parameters of the TVO step.
 
         Example:
-            >>> dsk.pipeline.set_validation_method('Stratified K-Fold Cross-Validation', params={'number_of_folds':3})
-            >>> dsk.pipeline.set_classifier('PME', params={"classification_mode":'RBF','distance_mode':'L1'})
-            >>> dsk.pipeline.set_training_algorithm('Hierarchical Clustering with Neuron Optimization', params = {'number_of_neurons':10})
-            >>> dsk.pipeline.set_tvo({'label_column':'Label', 'ignore_columns': ['Subject', 'Rep']})
+            >>> client.pipeline.set_validation_method('Stratified K-Fold Cross-Validation', params={'number_of_folds':3})
+            >>> client.pipeline.set_classifier('PME', params={"classification_mode":'RBF','distance_mode':'L1'})
+            >>> client.pipeline.set_training_algorithm('Hierarchical Clustering with Neuron Optimization', params = {'number_of_neurons':10})
+            >>> client.pipeline.set_tvo({'label_column':'Label', 'ignore_columns': ['Subject', 'Rep']})
         """
         self._tvo_call = call = self._kb.functions.create_train_and_validation_call(
             "tvo"
@@ -1085,7 +1085,7 @@ class Pipeline(object):
 
         fg =  {'name':'Downsample with Min Max Scaling', 'params':{"columns": ['gyrZ','gyrX'] , "new_length": 15}}
 
-        fg_new = dsk.pipeline.iterate_columns(fg, n_columns=1)
+        fg_new = client.pipeline.iterate_columns(fg, n_columns=1)
 
         >> print(fg_new)
         >> [{'name': 'Downsample with Min Max Scaling', 'params': {'columns': ['gyrX'], 'new_length': 15}},
@@ -1325,7 +1325,7 @@ class Pipeline(object):
         label=None,
         feature_columns=None,
         class_map=None,
-        dtype=int,
+        dtype=np.int32,
     ):
         if label is None:
             label = self._label_column
